@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2015-2017 by the Free Software Foundation, Inc.
+# Copyright (C) 2015-2018 by the Free Software Foundation, Inc.
 #
 # This file is part of Postorius.
 #
@@ -16,11 +16,13 @@
 # You should have received a copy of the GNU General Public License along with
 # Postorius.  If not, see <http://www.gnu.org/licenses/>.
 
-from __future__ import absolute_import, unicode_literals
 
 from postorius import utils
 from postorius.models import MailmanApiError
 from mailmanclient import MailmanConnectionError
+import logging
+
+logger = logging.getLogger(__name__)
 
 
 __all__ = [
@@ -37,6 +39,6 @@ class PostoriusMiddleware(object):
         return self.get_response(request)
 
     def process_exception(self, request, exception):
-        if isinstance(exception, MailmanApiError) or isinstance(
-                exception, MailmanConnectionError):
+        if isinstance(exception, (MailmanApiError, MailmanConnectionError)):
+            logger.exception('Mailman REST API not available')
             return utils.render_api_error(request)
