@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2012-2017 by the Free Software Foundation, Inc.
+# Copyright (C) 2012-2018 by the Free Software Foundation, Inc.
 #
 # This file is part of Postorius.
 #
@@ -15,7 +15,6 @@
 # You should have received a copy of the GNU General Public License along with
 # Postorius.  If not, see <http://www.gnu.org/licenses/>.
 
-from __future__ import absolute_import, unicode_literals
 
 import os
 import vcr
@@ -23,8 +22,8 @@ import logging
 
 from django.conf import settings
 from django.contrib import messages
-from django.core.urlresolvers import reverse
-from django.test import TestCase
+from django.urls import reverse
+from django.test import TransactionTestCase
 from mock import MagicMock
 from six import binary_type, text_type, PY3
 from six.moves.urllib_parse import (
@@ -37,13 +36,18 @@ vcr_log = logging.getLogger('vcr')
 vcr_log.setLevel(logging.WARNING)
 
 
+def get_test_file(*fileparts):
+    return os.path.join(os.path.dirname(__file__), "test_data", *fileparts)
+get_test_file.__test__ = False  # noqa: E305
+
+
 def reorder_request_params(request):
     def reorder_params(params):
         parsed = None
         if PY3:
             if isinstance(params, binary_type):
                 params = params.decode("ascii")
-                parsed = parse_qsl(params, encoding="utf-8")
+            parsed = parse_qsl(params, encoding="utf-8")
         else:
             parsed = parse_qsl(params)
         if parsed:
@@ -79,10 +83,21 @@ def filter_response_headers(response):
 
 
 def get_vcr(**kwargs):
+    # Use the POSTORIUS_VCR_RECORD_MODE environment variable to set the record
+    # mode. By default, this value is set to 'once'.
+    # See http://vcrpy.readthedocs.io/en/latest/usage.html#record-modes
+    # for more details about all the record modes.
+    vcr_record_mode = os.getenv('POSTORIUS_VCR_RECORD_MODE', 'once')
+    if vcr_record_mode not in ('once', 'all', 'none', 'new_episodes'):
+        vcr_log.warning('{} is not a valid VCR.py mode, '
+                        'using once as default'.format(vcr_record_mode))
+        vcr_record_mode = 'once'
+
     return vcr.VCR(
         filter_headers=['authorization', 'user-agent', 'date'],
         before_record=reorder_request_params,
         before_record_response=filter_response_headers,
+        record_mode=vcr_record_mode,
         **kwargs
     )
 
@@ -141,8 +156,7 @@ def create_mock_member(properties=None):
     return mock_object
 
 
-class ViewTestCase(TestCase):
-
+class ViewTestCase(TransactionTestCase):
     use_vcr = True
     _fixtures_dir = os.path.join(os.path.abspath(
         os.path.dirname(__file__)), 'fixtures', 'vcr_cassettes')
